@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Content-Type" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-01-24
+Plugin.define do
+name "Content-Type"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-01-24
+]
 version "0.1"
 description "This plugin identifies the document's content type."
 
@@ -14,7 +17,7 @@ description "This plugin identifies the document's content type."
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Extract conent type
