@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Meta-Geography" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-20
+Plugin.define do
+name "Meta-Geography"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-20
+]
 version "0.1"
 description "This plugin retrieves the geography from the meta geography, geo.position, geo.placename and geo.region tags."
 
