@@ -2,18 +2,18 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# ~ Brendan Coles bcoles@gmail.com
-# Added JavaScript detection
-# Added <embed> element detection
-# Added flash file path retrieval
-##
-Plugin.define "Adobe-Flash" do
-author "Caleb Anderson"
-version "0.2"
+Plugin.define do
+name "Adobe-Flash"
+authors [
+  "Caleb Anderson",
+  "Brendan Coles <bcoles@gmail.com>", # v0.2 # Added JavaScript detection. Added <embed> element detection. Added flash file path retrieval. 
+  "Andrew Horton", # v0.3 # 2019-07-10 # Added website field.
+]
+version "0.3"
 description "This plugin identifies instances of embedded adobe flash files."
+website "https://get.adobe.com/flashplayer/"
 
 # Google results as at 2010-10-14 #
 # 244 for "your browser does not support flash"
