@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Updated regex and version detection
-##
-Plugin.define "Advanced-Image-Hosting-Script" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-30
+Plugin.define do
+name "Advanced-Image-Hosting-Script"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-30
+  # v0.2 # Updated regex and version detection. 
+]
 version "0.2"
 description "AIHS is a highly-flexible advanced image hosting solution for anyone who wants to offer an image hosting services of any kind."
 website "http://yabsoft.com/aihs-feature.php"
