@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Advantech-WebAccess" do
-author "Brendan Coles <bcoles@gmail.com>" # 2013-01-09
+Plugin.define do
+name "Advantech-WebAccess"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2013-01-09
+]
 version "0.1"
 description "Advantech WebAccess HMI/SCADA software"
 website "http://webaccess.advantech.com/"
