@@ -2,13 +2,17 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "adxstudio-cms" do
-author "Aung Khant <http://yehg.net/>" # 2012-02-12
-version "0.1"
-description "ADXStudio CMS - http://www.adxstudio.com"
-
+Plugin.define do
+name "adxstudio-cms"
+authors [
+  "Aung Khant <http://yehg.net/>", # 2012-02-12
+  "Andrew Horton", # v0.2 # 2019-07-10 # Added website field.
+]
+version "0.2"
+description "ADXStudio CMS"
+website "http://www.adxstudio.com"
 
 
 # Matches #
