@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "AiCart" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-19
+Plugin.define do
+name "AiCart"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-19
+]
 version "0.1"
 description "AiCart shopping cart software is created in PHP and uses a simple template structure, makes it very flexible and easy to modify. The data in AiCart is stored in a MySQL database."
 website "http://www.aicart.ca/"
