@@ -2,14 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-01-07 #
-# Updated version detection method
-# Updated matches
-##
-Plugin.define "AirvaeCommerce" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-22
+Plugin.define do
+name "AirvaeCommerce"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-22
+  # v0.2 # 2011-01-07 # Updated version detection method. Updated matches. 
+]
 version "0.2"
 description "Airvae Commerce 3.0 is a flexible, powerful, e-commerce shopping cart software offering clients, web developers, and I.T. professionals the perfect solution to deploy sophisticated, extensible, e-commerce solutions."
 website "http://www.airvaecommerce.com/"
