@@ -2,12 +2,17 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Alpha-Five" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-20
-version "0.1"
-description "The Alpha Five Application Server allows you to deploy the web applications you build with Alpha Five Developer. Each license allows you to install the server on one PC. - https://www.alphasoftware.com/shop/"
+Plugin.define do
+name "Alpha-Five"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-20
+  "Andrew Horton", # v0.2 # 2019-07-10 # Added website field.
+]
+version "0.2"
+description "The Alpha Five Application Server allows you to deploy the web applications you build with Alpha Five Developer. Each license allows you to install the server on one PC."
+website "https://www.alphasoftware.com/"
 
 # ShodanHQ results as at 2011-08-20 #
 # 463 for Alpha Five
