@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "AM4SS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-11
+Plugin.define do
+name "AM4SS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-11
+]
 version "0.1"
 description "Advanced Management For Services Sites (AM4SS)"
 website "http://am4ss.org/"
