@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-17 # Andrew Horton
-# Added website parameter
-##
-Plugin.define "AMX-Mod-X" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-09-04
+Plugin.define do
+name "AMX-Mod-X"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-09-04
+  "Andrew Horton", # v0.2 # 2016-04-17 # Added website parameter. 
+]
 version "0.2"
 description "AMX Mod X is a versatile Half-Life metamod plugin which is targetted toward server administration."
 website "http://www.amxmodx.org/"
@@ -28,7 +29,7 @@ matches [
 ]
 
 # Grab mySQL username, server and database details
-def passive
+passive do
 	m=[]
 
 	if @body =~ /amx_sql_host[\s]+"([^\"]*)"/ and @body =~ /amx_sql_user[\s]+"([^\"]+)"/ and @body =~ /amx_sql_pass[\s]+"([^\"]*)"/
