@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "AP-Router" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-14
+Plugin.define do
+name "AP-Router"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-14
+]
 version "0.1"
 description "AP Router [Brazilian]"
 website "http://aprouter.com.br/"
