@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2012-05-08
-# Added 3 matches from Steve 'Ashcrow' Milner
-##
-Plugin.define "Apache-Wicket" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-27
+Plugin.define do
+name "Apache-Wicket"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-27
+  # v0.2 # 2012-05-08 # Added 3 matches from Steve 'Ashcrow' Milner. 
+]
 version "0.2"
 description "Apache Wicket, commonly referred to as Wicket, is a lightweight component-based web application framework for the Java programming language"
 website "http://wicket.apache.org/"
