@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Atvise-webMI" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-04-11
+Plugin.define do
+name "Atvise-webMI"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-04-11
+]
 version "0.1"
 description "Web-based HMI server - atvise webMI compliant web servers can be extremely slim and work on the smallest hardware."
 website "http://www.atvise.com/en/how-it-works"
