@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Auxilium-PetRatePro" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-09-18
+Plugin.define do
+name "Auxilium-PetRatePro"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-09-18
+]
 version "0.1"
 description "Auxilium PetRatePro"
 website "http://www.auxiliumsoftware.com/PetRatePro/"
