@@ -2,11 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-Plugin.define "Axis-PrintServer" do
-author "Andrew Horton"
+Plugin.define do
+name "Axis-PrintServer"
+authors [
+  "Andrew Horton",
+]
 version "0.1"
 description "Axis 540/542 Network Print Server"
 website "http://www.axis.com/products/axis_540p/index.htm"
