@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "c99-Shell" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-08
+Plugin.define do
+name "c99-Shell"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-08
+]
 version "0.1"
 description "c99 PHP Backdoor"
 
@@ -24,7 +27,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
         m=[]
 
 	# Get local file path # Must start with "/" to avoid c99 source
