@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-01-10 #
-# Updated version detection
-##
-Plugin.define "Campsite" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-15
+Plugin.define do
+name "Campsite"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-15
+  # v0.2 # 2011-01-10 # Updated version detection. 
+]
 version "0.2"
 description "Campsite is a multilingual content management system (CMS) for news websites."
 website "http://www.sourcefabric.org/"
