@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Card-Reader-Adapter" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-19
+Plugin.define do
+name "Card-Reader-Adapter"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-19
+]
 version "0.1"
 description "Card Reader Adapter - Unknown manufacturer [Korean]"
 # Returns "Card Reader Adapter" over SNMP
@@ -28,7 +31,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Version Detection # HTTP Server Header
