@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Cerberus-Helpdesk" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-10-22
+Plugin.define do
+name "Cerberus-Helpdesk"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-10-22
+]
 version "0.1"
 description "Cerberus Helpdesk - fast and flexible web-based platform for business collaboration and automation"
 website "http://www.cerberusweb.com/"
