@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.1 # 2014-07-20 #
-# Initial version
-##
-Plugin.define "cgit" do
-author "Fabian Affolter <fabian@engineering.ch>" # 2014-07-20
+Plugin.define do
+name "cgit"
+authors [
+  "Fabian Affolter <fabian@engineering.ch>", # 2014-07-20
+  # v0.1 # 2014-07-20 # Initial version. 
+]
 version "0.1"
 description "A web frontend for git repositories written in C."
 website "http://git.zx2c4.com/cgit/"
@@ -32,7 +33,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
     # Version detection
 	if @body =~ /<meta name='generator' content='cgit v([^\s]+)'\/>/
