@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Check-Point-Firewall" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-18
+Plugin.define do
+name "Check-Point-Firewall"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-18
+]
 version "0.1"
 description "Check Point Firewall"
 website "http://www.checkpoint.com/"
