@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "chillyCMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-09-08
+Plugin.define do
+name "chillyCMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-09-08
+]
 version "0.1"
 description "chillyCMS is a Content Management System. This is a software which allows you to create a website without any programming skills."
 website "http://chillycms.bplaced.net/"
