@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "cInvoice" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-07-06
+Plugin.define do
+name "cInvoice"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-07-06
+]
 version "0.1"
 description "Forperfect cInvoice system - web-based invoice system. Requires PHP and MySQL."
 website "http://www.forperfect.com/seo/cinvoice.php"
