@@ -2,15 +2,16 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-23 # Andrew Horton
-# Moved patterns from passive function to matches[]
-##
-
-Plugin.define "Citrix-NetScaler" do
-author "Aung Khant <http://yehg.net/>" # 2011-02-04
-version "0.2"
+Plugin.define do
+name "Citrix-NetScaler"
+authors [
+  "Aung Khant <http://yehg.net/>", # 2011-02-04
+  "Andrew Horton", # v0.2 # 2016-04-23 # Moved patterns from passive function to matches[]. 
+  "Bhavin Senjaliya", # v0.3 # 2017-11-27 # Add NSC_ cookie. 
+]
+version "0.3"
 description "Citrix NetScaler  - http://www.citrix.com/netscaler"
 
 matches [
@@ -19,6 +20,8 @@ matches [
 
 	{ :version=>/NS\-CACHE\-(\d{1,4}\.\d{1,4}):/, :search=>"headers[via]" },	
 
+	{ :search => "headers[set-cookie]", :regexp => /^NSC_/, :name=>"NSC_ cookie" },
+
 ]
 
 end
