@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "ClipBucket" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-01-18
+Plugin.define do
+name "ClipBucket"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-01-18
+]
 version "0.1"
 description "ClipBucket is an OpenSource Multimedia Management Script"
 website "http://clip-bucket.com"
