@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "CmyDocument" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-04
+Plugin.define do
+name "CmyDocument"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-11-04
+]
 version "0.1"
 description "CmyDocument is a Content Management and Document Management application"
 website "http://cmydocument.com/"
