@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Collabtive" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-06-10
+Plugin.define do
+name "Collabtive"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-06-10
+]
 version "0.1"
 description "Collabtive - Open Source Collaboration"
 website "http://collabtive.o-dyn.de/"
