@@ -2,17 +2,18 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-##
-Plugin.define "Content-Language" do
-author "Peter van der Laan"
+Plugin.define do
+name "Content-Language"
+authors [
+  "Peter van der Laan",
+]
 version "0.1"
 description "Detect the content-language setting from the HTTP header."
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# HTTP Server Header # Content-Language
