@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "crossdomain_xml" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-01-09
+Plugin.define do
+name "crossdomain_xml"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-01-09
+]
 version "0.1"
 description "This plugin extracts allowed domain from crossdomain.xml"
 
