@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "CS-Cart" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-09-12
+Plugin.define do
+name "CS-Cart"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-09-12
+]
 version "0.1"
 description "CS-Cart is a full e-commerce solution for small to medium sized businesses. The software uses PHP4 and MySQL to provide an easy, quick and flexible interface, allowing you to produce a high functionality on-line store in minutes. It is all 100% template driven!"
 website "http://www.cs-cart.com/"
