@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "D-Link-Network-Camera" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-22
+Plugin.define do
+name "D-Link-Network-Camera"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-22
+]
 version "0.1"
 description "D-Link network camera web interface"
 website "http://www.dlink.com/"
