@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "darkstat" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-02-17
+Plugin.define do
+name "darkstat"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-02-17
+]
 version "0.1"
 description "darkstat captures network traffic, calculates statistics about usage, and serves reports over HTTP."
 website "http://unix4lyfe.org/darkstat/"
