@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "dir2web-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-08-08
+Plugin.define do
+name "dir2web-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-08-08
+]
 version "0.1"
 description "dir2web CMS"
 website "http://www.dir2web.it/"
