@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "DORG" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-22
+Plugin.define do
+name "DORG"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-22
+]
 version "0.1"
 description "DORG is an Disc organization script which makes it easier for customers and businesses to find their software."
 website "http://www.discorganizer.org/"
