@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "DotA-OpenStats" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-12-19
+Plugin.define do
+name "DotA-OpenStats"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-12-19
+]
 version "0.1"
 description "DotA OpenStats - MySQL based web statistics site for DotA games. - Requires PHP and MySQL"
 website "https://sourceforge.net/projects/dotaopenstats/"
