@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "dwr" do
-author "Aung Khant <http://yehg.net/>" # 2012-02-12
+Plugin.define do
+name "dwr"
+authors [
+  "Aung Khant <http://yehg.net/>", # 2012-02-12
+]
 version "0.1"
 description "Direct Web Remoting - http://directwebremoting.org"
 
