@@ -2,11 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "DynaWeb-httpd" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-07
-version "0.1"
+Plugin.define do
+name "DynaWeb-httpd"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-07
+  "Andrew Horton", # 2019-07-10 # Fix warning: character class has duplicated range
+]
+version "0.2"
 description "DynaWeb web server. Ships with Sun Microsystem's AnswerBook"
 website "http://www.oracle.com/"
 
@@ -19,11 +23,11 @@ website "http://www.oracle.com/"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Version Detection # HTTP Server Header
-	if @headers["server"] =~ /^dwhttpd\/([^\s]+) \(([^\s^;^\)]+; [^\s^\)]+)\)$/
+	if @headers["server"] =~ /^dwhttpd\/([^\s]+) \(([^\s;\)]+; [^\s\)]+)\)$/
 		m << { :version=>"#{$1}" }
 		m << { :string=>"#{$2}" }
 	end
