@@ -2,16 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.3 # 2016-04-17 # Andrew Horton
-# Added website parameter and description
-##
-# Version 0.2 # 2011-02-24 #
-# Updated version detection
-##
-Plugin.define "easyLink-Web-Solutions" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-09-03
+Plugin.define do
+name "easyLink-Web-Solutions"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-09-03
+  # v0.2 # 2011-02-24 # Updated version detection. 
+  "Andrew Horton", # v0.3 # 2016-04-17 # Added website parameter and description. 
+]
 version "0.3"
 description "German Content Management System"
 website "http://www.mountaingrafix.eu/tag/easylink/"
