@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Epiware" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-09-16
+Plugin.define do
+name "Epiware"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-09-16
+]
 version "0.1"
 description "Epiware - Enterprise Document Management"
 website "http://www.epiware.com/"
