@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "eTicket" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-09-15
+Plugin.define do
+name "eTicket"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-09-15
+]
 version "0.1"
 description "eTicket is a PHP-based electronic support ticket system that can receive tickets via email (pop3/pipe) or a web form."
 website "http://www.eticketsupport.com/"
