@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "FEX" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-02-22
+Plugin.define do
+name "FEX"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-02-22
+]
 version "0.1"
 description "F*EX (Frams's Fast File EXchange) is a service that can be used to allow users anywhere on the Internet to exchange files of ANY size quickly and conveniently."
 website "http://fex.rus.uni-stuttgart.de/fex.html"
