@@ -1,12 +1,14 @@
-# coding: ascii-8bit
 ##
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Fidion-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-09-12 
+Plugin.define do
+name "Fidion-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-09-12 
+]
 version "0.1"
 description "CMS"
 website "http://www.fidion.de/"
