@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "FITELnet-Router" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-30
+Plugin.define do
+name "FITELnet-Router"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-30
+]
 version "0.1"
 description "FITELnet router"
 website "http://www.furukawa.co.jp/fitelnet/"
@@ -17,7 +20,7 @@ website "http://www.furukawa.co.jp/fitelnet/"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# HTTP Server Header
