@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Fizmez-Web-Server" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-08-12
+Plugin.define do
+name "Fizmez-Web-Server"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-08-12
+]
 version "0.1"
 description "Fizmez Web Server - A webserver written entirely in Java. Useful for learning about servers and daemons. The whole package comes in at under 20Kbytes compressed."
 website "http://sourceforge.net/projects/fizmezwebserver/"
