@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Flat-File-Guestbook" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-12
+Plugin.define do
+name "Flat-File-Guestbook"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-12
+]
 version "0.1"
 description "The Flat File PHP Guestbook is designed to be lightweight, easy on the server, and simple to install. Requires PHP 4+."
 website "http://www.advancebydesign.com/software/php-scripts-and-programmes/mail-and-feedback/php-flat-file-guestbook.html"
