@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "FreakAuth" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-11
+Plugin.define do
+name "FreakAuth"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-11
+]
 version "0.1"
 description "FreakAuth is a simple authentication library for the Code Igniter PHP framework"
 website "http://freakauth.4webby.com/"
@@ -34,7 +37,7 @@ matches [
 
 ]
  # Passive #
-def passive
+passive do
 	m=[]
 
 	# FreakAuth Cookie
