@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Free-Realty" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-05-15
+Plugin.define do
+name "Free-Realty"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-05-15
+]
 version "0.1"
 description "Free Realty is primarily designed for real estate agents and offices to list properties on the internet."
 website "http://freerealty.rwcinc.net/"
