@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "fsaATLAS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-01-29
+Plugin.define do
+name "fsaATLAS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-01-29
+]
 version "0.1"
 description "fsaAtlas is an international student and scholar management system."
 website "http://www.sungardhe.com/Solutions/fsaATLAS/"
