@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-10 #
-# Updated version detection
-##
-Plugin.define "GeekLog" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-09-25
+Plugin.define do
+name "GeekLog"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-09-25
+  # v0.2 # 2011-02-10 # Updated version detection. 
+]
 version "0.2"
 description "Geeklog is an open source application for managing dynamic web content. It is written in PHP and supports MySQL, PostgreSQL, or MS SQL as the database backend."
 website "http://www.geeklog.net/"
