@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Gitorious" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-13
+Plugin.define do
+name "Gitorious"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-13
+]
 version "0.1"
 description "Gitorious provides open source infrastructure for hosting open source projects that use Git - Requires: Ruby."
 website "https://gitorious.org/gitorious"
