@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Google-Results" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-01-25
+Plugin.define do
+name "Google-Results"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-01-25
+]
 version "0.1"
 description "This plugin identifies Google search results pages and extracts the result URLs, query and number of results from the results."
 website "http://www.google.com/"
@@ -22,7 +25,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Extract Google results
