@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-# Version 0.2 by Andrew Horton. Updated everything
-
-Plugin.define "HP-OfficeJet-Printer" do
-author "Andrew Horton"
+Plugin.define do
+name "HP-OfficeJet-Printer"
+authors [
+  "Andrew Horton",
+  # v0.2 # Andrew Horton. Updated everything
+]
 version "0.2"
 description "HP Officejet Pro and Officejet printers"
 website "http://www.hp.com/products1/inkjetprinter/officejet.html"
