@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Hughes-Voice-Appliance" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-11-11
+Plugin.define do
+name "Hughes-Voice-Appliance"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-11-11
+]
 version "0.1"
 description "Hughes VoIP Appliance for HughesNet integration"
 website "http://www.hughes.com/"
