@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Hycus-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-09-12
+Plugin.define do
+name "Hycus-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-09-12
+]
 version "0.1"
 description "India's first CMS. Free and open-source PHP based CMS."
 website "http://www.hycus.com/"
