@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-20 # Andrew Horton
-# Moved patterns from passive function to matches[]
-##
-Plugin.define "HyNetOS-httpd" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-11
+Plugin.define do
+name "HyNetOS-httpd"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-11
+  "Andrew Horton", # v0.2 # 2016-04-20 # Moved patterns from passive function to matches[]. 
+]
 version "0.2"
 description "HyNetOS is a network operating system specifically designed for embedded systems, where computing and memory resources are limited."
 website "http://www.msc-ge.com/en/produkte/elekom/mc/hyperstone/sw_hynetos.html"
