@@ -2,13 +2,17 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Hyperic-HQ" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-08-19
-version "0.1"
+Plugin.define do
+name "Hyperic-HQ"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-08-19
+  "Andrew Horton", # v0.2 # 2019-07-10 # Removed Homepage: from the website
+]
+version "0.2"
 description "Hyperic HQ - platform for custom web application monitoring and performance management in physical, virtual, and cloud environments."
-website "Homepage: http://www.vmware.com/products/application-platform/vfabric-hyperic.html"
+website "http://www.vmware.com/products/application-platform/vfabric-hyperic.html"
 
 # Default Port # 7443
 # Default User # hqadmin
