@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "ICEshop" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-02-26
+Plugin.define do
+name "ICEshop"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-02-26
+]
 version "0.1"
 description "ICEshop e-commerce"
 website "http://www.iceshop.nl/"
