@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Ilient-SysAid" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-24
+Plugin.define do
+name "Ilient-SysAid"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-24
+]
 version "0.1"
 description "Ilient SysAid IT Help Desk Software"
 website "http://www.ilient.com/"
