@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "IMGallery" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-27
+Plugin.define do
+name "IMGallery"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-27
+]
 version "0.1"
 description "image gallery web app"
 website "http://www.imgallery.zor.pl"
