@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Indices" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-17
+Plugin.define do
+name "Indices"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-17
+]
 version "0.1"
 description "Indices is a set of hacks that makes Apache's default directory index pages pretty and more usable."
 website "http://antisleep.com/software/indices"
