@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Indico" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-11
+Plugin.define do
+name "Indico"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-11
+]
 version "0.1"
 description "Indico - Integrated Digital Conference - allows you to manage complex conferences, workshops and meetings."
 website "http://indico.cern.ch/"
@@ -35,7 +38,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# MAKACSESSION Cookie
