@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "iScripts-MultiCart" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-11
+Plugin.define do
+name "iScripts-MultiCart"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-11
+]
 version "0.1"
 description "iScripts MultiCart is a multi vendor shopping cart with a single backend."
 website "http://www.iscripts.com/multicart/"
