@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "jetNEXUS-Load-Balancer" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-23
+Plugin.define do
+name "jetNEXUS-Load-Balancer"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-23
+]
 version "0.1"
 description "jetNEXUS provide leading edge load balancing and traffic management solutions to accelerate application performance and availability, enabling clients to create and deliver resilient and scalable online services."
 website "http://www.jetnexus.com/"
@@ -16,7 +19,7 @@ website "http://www.jetnexus.com/"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# jetNEXUS Header
