@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Jetty" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-22
+Plugin.define do
+name "Jetty"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-22
+]
 version "0.1"
 description "Jetty is a pure Java application server. Jetty provides an HTTP server, HTTP client, and javax.servlet container."
 website "http://jetty.codehaus.org/jetty/"
