@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-03-19 # Brendan Coles <bcoles@gmail.com>
-# Updated regex
-##
-Plugin.define "Juniper-Load-Balancer" do
-author "Aung Khant <http://yehg.net/>" # 2011-02-04
+Plugin.define do
+name "Juniper-Load-Balancer"
+authors [
+  "Aung Khant <http://yehg.net/>", # 2011-02-04
+  "Brendan Coles <bcoles@gmail.com>", # v0.2 # 2011-03-19 # Updated regex. 
+]
 version "0.2"
 description "Juniper Networks Application Acceleration and Load Balancing Platforms"
 website "http://juniper.net/ - Note: This will slow down your web app pentest scanning. Use only manual fuzzing with time throttling."
@@ -16,7 +17,7 @@ website "http://juniper.net/ - Note: This will slow down your web app pentest sc
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Cookie
