@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Kajona" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-07-19
+Plugin.define do
+name "Kajona"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-07-19
+]
 version "0.1"
 description "Kajona - Open Source Content Management System - Requires PHP & MySQL"
 website "http://www.kajona.de/"
