@@ -2,11 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-Plugin.define "KodiTV" do
-author "Andrew Horton"
+Plugin.define do
+name "KodiTV"
+authors [
+  "Andrew Horton",
+]
 version "0.1"
 description "KODI is a media center. It was formerly known as XBMC Media Center."
 website "https://kodi.tv/"
