@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Kohana" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-10
+Plugin.define do
+name "Kohana"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-10
+]
 version "0.1"
 description "Kohana is an elegant HMVC PHP5 framework that provides a rich set of components for building web applications."
 website "http://kohanaframework.org/"
@@ -22,7 +25,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# kohanasession cookie
