@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "LetoDMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-08-24
+Plugin.define do
+name "LetoDMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-08-24
+]
 version "0.1"
 description "LetoDMS is an open-source document-management-system based on PHP and MySQL published under the GPL."
 website "http://www.letodms.com/"
