@@ -2,20 +2,18 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.4 # 2016-04-21 # Andrew Horton
-# Moved patterns from passive function to matches[]
-##
-# Version 0.3 # 2011-03-06 #
-# Updated OS detection
-##
-# Version 0.2 # 2011-01-25 #
-# Updated version detection
-##
-Plugin.define "lighttpd" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-26
-version "0.4"
+Plugin.define do
+name "lighttpd"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-26
+  # v0.2 # 2011-01-25 # Updated version detection. 
+  # v0.3 # 2011-03-06 # Updated OS detection. 
+  "Andrew Horton", # v0.4 # 2016-04-21 # Moved patterns from passive function to matches[]. 
+	"Andrew Horton", # v0.5 # 2019-07-10 # Fix warning: character class has duplicated range
+]
+version "0.5"
 description "Lightweight open-source web server."
 website "http://www.lighttpd.net/"
 
@@ -27,7 +25,7 @@ matches [
 	{ :regexp=>/lighttpd/, :search=>"headers[server]" },
 
 	# Version Detection # Server HTTP header
-	{ :version=>/^[\s]*lighttpd\/([^\s^\r^\n]+)/, :search=>"headers[server]" },
+	{ :version=>/^[\s]*lighttpd\/([^\s]+)/, :search=>"headers[server]" },
 
 	# OS Detection # Server HTTP header
 	{ :os=>/^[\s]*lighttpd \(([^\)]+)\)/, :search=>"headers[server]" },	
