@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "LK-IHC-Controller" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-01
+Plugin.define do
+name "LK-IHC-Controller"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-01
+]
 version "0.1"
 description "Visualization of an IHC Control electrical installation."
 website "http://www.prolor.dk/ihc.php"
