@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Updates matches and version detection
-##
-Plugin.define "Loggix" do
-author "Brendan Coles <bcoles at gmail dot com>" # 2010-06-15
+Plugin.define do
+name "Loggix"
+authors [
+  "Brendan Coles <bcoles at gmail dot com>", # 2010-06-15
+  # v0.2 # Updates matches and version detection. 
+]
 version "0.2"
 description "Loggix is a really simple, lightweight PHP and SQlite driven weblog/cms engine."
 website "http://loggix.gotdns.org/"
