@@ -2,15 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-07-30 # Brendan Coles <bcoles@gmail.com>
-# Added examples URLs, added passive match and added google dork
-##
-# Version 0.3 Andrew Horton. Replaced aggressive function with matches
-
-Plugin.define "MapServer" do
-author "Aung Khant, http://yehg.net"
+Plugin.define do
+name "MapServer"
+authors [
+  "Aung Khant, http://yehg.net",
+  "Brendan Coles <bcoles@gmail.com>", # v0.2 # 2011-07-30 # Added examples URLs, added passive match and added google dork. 
+  "Andrew Horton", # v0.3 # Replaced aggressive function with matches
+]
 version "0.3"
 description "Detect MapServer CGI application (http://www.mapserver.org/)"
 
@@ -33,7 +33,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 	# Error Message # Empty QUERY_STRING
 	if @body == "No query information to decode. QUERY_STRING is set, but empty.\n"
