@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "MemHT-Portal" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-02-08
+Plugin.define do
+name "MemHT-Portal"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-02-08
+]
 version "0.1"
 description "MemHT Portal is a Free PHP CMS and Blog. It permits the creation and the management online of websites with few and easy steps. It's completely customizable, expandable and suitable for all needs."
 website "http://www.memht.com/"
