@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-03-05 # Brendan Coles <bcoles@gmail.com>
-# Updated error code string detection to reduce false positives
-##
-Plugin.define "Microsoft-ODBC-Error" do
-author "Caleb Anderson"
+Plugin.define do
+name "Microsoft-ODBC-Error"
+authors [
+  "Caleb Anderson",
+  "Brendan Coles <bcoles@gmail.com>", # v0.2 # 2011-03-05 # Updated error code string detection to reduce false positives. 
+]
 version "0.2"
 description "This plugin identifies Microsoft ODBC error codes."
 
@@ -21,7 +22,7 @@ description "This plugin identifies Microsoft ODBC error codes."
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# ODBC Error Code
