@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Microsys-PROMOTIC" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-04-05
+Plugin.define do
+name "Microsys-PROMOTIC"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-04-05
+]
 version "0.1"
 description "Microsys PROMOTIC web interface - PROMOTIC is a complex SCADA object software tool for creating applications that monitor, control and display technological processes in various industrial areas."
 website "http://www.promotic.eu/en/promotic/scada-pm.htm"
