@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Mioot-Live-Chat" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-06
+Plugin.define do
+name "Mioot-Live-Chat"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-06
+]
 version "0.1"
 description "Mioot live chat JavaScript"
 website "http://www.mioot.com/"
