@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "MyWebFTP" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-20
+Plugin.define do
+name "MyWebFTP"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-20
+]
 version "0.1"
 description "MyWebFTP web FTP client. MyWebFTP is designed for a professional web developer to do all your daily online file management tasks from one place. Install MyWebFTP on one of your websites, and it will allow you to quickly and efficiently manage files of all your websites via FTP."
 website "http://mywebftp.com/"
