@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "NCR-iTRAN-3000t-Imaging-Transport" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-11-16
+Plugin.define do
+name "NCR-iTRAN-3000t-Imaging-Transport"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-11-16
+]
 version "0.1"
 description "A full function, image-based table top check imaging and payment processing device"
 website "http://www.ncr.com/products-and-services/payment-and-imaging/check-and-document-imaging/low-to-mid-volume-item-processing/ncr-itran-3000t-imaging-transport"
