@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Netquery" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-20
+Plugin.define do
+name "Netquery"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-20
+]
 version "0.1"
 description "Netquery is a complete PHP/SQL open-source toolkit of network utilities. Available as a standalone application and as a module for the following CMSs: e107, PHP-Fusion, Xaraya, Xoops and Zikula."
 website "http://virtech.org/tools/"
