@@ -1,12 +1,14 @@
-# coding: ascii-8bit
 ##
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Netsnap-Web-Camera" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-10
+Plugin.define do
+name "Netsnap-Web-Camera"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-10
+]
 version "0.1"
 description "Netsnap java client web interface for video cameras"
 
