@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "NextGEN-Gallery" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-04
+Plugin.define do
+name "NextGEN-Gallery"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-04
+]
 version "0.1"
 description "NextGEN Gallery is a full integrated Image Gallery plugin for WordPress with dozens of options and features."
 website "http://nextgen-gallery.com"
