@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Nucleus-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-23
+Plugin.define do
+name "Nucleus-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-23
+]
 version "0.1"
 description "Nucleus CMS"
 website "http://nucleuscms.org/"
