@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Nucleus" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-10-26
+Plugin.define do
+name "Nucleus"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-10-26
+]
 version "0.1"
 description "Nucleus Webserver"
 
@@ -13,7 +16,7 @@ description "Nucleus Webserver"
 
 
 # HTTP Header
-def passive
+passive do
 	m=[]
 
 	# Server
