@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "OBM" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-12-28
+Plugin.define do
+name "OBM"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-12-28
+]
 version "0.1"
 description "OBM is a free messaging and collaboration software including Groupware, Messaging, CRM, LDAP, Domain management, Smartphones and PDA synchronization"
 website "http://obm.org/"
