@@ -2,15 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-
-# Version 0.2
-# remove :certainty and :name, change regexp to text
-
-Plugin.define "OkiPBX" do
-author "Andrew Horton"
+Plugin.define do
+name "OkiPBX"
+authors [
+  "Andrew Horton",
+  # v0.2 # remove :certainty and :name, change regexp to text
+]
 version "0.2"
 description "OKI PBX (phone exchange) http://www.oki.com/en/iptel/products/mxsx/maintenance.html"
 
