@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "OpenKM" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-01-09
+Plugin.define do
+name "OpenKM"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-01-09
+]
 version "0.1"
 description "OpenKM - Open Source Electronic Document Management System"
 website "http://www.openkm.com/en/"
