@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "OpenLabyrinth" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-03
+Plugin.define do
+name "OpenLabyrinth"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-03
+]
 version "0.1"
 description "OpenLabyrinth is a web application for authoring and delivering virtual patient and other decision path and maze-like activities. It is written in ASP/VBScript and requires an ODBC SQL database."
 website "http://sourceforge.net/projects/openlabyrinth/"
@@ -30,7 +33,7 @@ matches [
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Form
