@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "osTicket" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-24
+Plugin.define do
+name "osTicket"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-24
+]
 version "0.1"
 description "osTicket is a widely-used open source support ticket system - Requires: PHP and MySQL"
 website "http://www.osticket.com/"
