@@ -2,16 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.3 # 2016-04-17 # Andrew Horton
-# Added website parameter and description
-##
-# Version 0.2 #
-# Updated regex and version detection
-##
-Plugin.define "PHPEasyData" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-16
+Plugin.define do
+name "PHPEasyData"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-16
+  # v0.2 # Updated regex and version detection. 
+  "Andrew Horton", # v0.3 # 2016-04-17 # Added website parameter and description. 
+]
 version "0.3"
 description "PHPEasyData is a French Content Management System"
 website "http://www.phpeasydata.com/"
