@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-17 # Andrew Horton
-# Added description
-##
-Plugin.define "PHP-Update" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-01
+Plugin.define do
+name "PHP-Update"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-01
+  "Andrew Horton", # v0.2 # 2016-04-17 # Added description. 
+]
 version "0.2"
 description "Open-source Content Management System. Homepage used to be http://www.php-update.co.uk"
 
