@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpCollab" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-17
+Plugin.define do
+name "phpCollab"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-17
+]
 version "0.1"
 description "phpCollab is an open source internet-enabled system for use in projects that require collaboration over the internet."
 website "http://www.php-collab.org/"
