@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpGreetCards" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-01
+Plugin.define do
+name "phpGreetCards"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-01
+]
 version "0.1"
 description "PHP greeting card mailer"
 website "http://www.w2b.ru/webapplications/index.php"
