@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-21 #
-# Updated version detection
-##
-Plugin.define "phPhotoAlbum" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-14
+Plugin.define do
+name "phPhotoAlbum"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-14
+  # v0.2 # 2011-02-21 # Updated version detection. 
+]
 version "0.2"
 description "PHP Photo Album"
 website "http://www.phphq.net/?script=phPhotoAlbum"
