@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phplist" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-04
+Plugin.define do
+name "phplist"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-04
+]
 version "0.1"
 description "phplist is the world's most popular open source email campaign manager."
 website "http://www.phplist.com/"
