@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpMyBackupPro" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-08-30
+Plugin.define do
+name "phpMyBackupPro"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-08-30
+]
 version "0.1"
 description "phpMyBackup Pro is a very easy to use, free, web-based MySQL backup application, licensed under the GNU GPL."
 website "http://www.phpmybackuppro.net/"
