@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpMyBible" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-04-24
+Plugin.define do
+name "phpMyBible"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-04-24
+]
 version "0.1"
 description "phpMyBible is an online collaborative project to make an e-book of the Holy Bible."
 website "http://sourceforge.net/projects/phpmybible/"
