@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "PHPOpenChat" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-23
+Plugin.define do
+name "PHPOpenChat"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-23
+]
 version "0.1"
 description "PHPOpenChat is a high performance php-based chat server software for a live chat-room"
 website "http://www.phpopenchat.org/"
