@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpPgAdmin" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-14 
+Plugin.define do
+name "phpPgAdmin"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-14 
+]
 version "0.1"
 description "phpPgAdmin is a web-based administration tool for PostgreSQL. It is perfect for PostgreSQL DBAs, newbies and hosting services"
 website "http://phppgadmin.sourceforge.net/"
