@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "phpRemoteView" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-24
+Plugin.define do
+name "phpRemoteView"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-24
+]
 version "0.1"
 description "phpRemoteView - web backdoor - allows users to browse the filesystem, edit files on the server, execute PHP code, or Shell commands, etc. Works on Windows and Unix servers"
 website "http://php.spb.ru/remview/"
