@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "PivotX" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-05-18
+Plugin.define do
+name "PivotX"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-05-18
+]
 version "0.1"
 description "PivotX - blog software"
 website "http://pivotx.net/"
