@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-25 #
-# Updated version detection
-##
-Plugin.define "Pixie" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-18
+Plugin.define do
+name "Pixie"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-18
+  # v0.2 # 2011-02-25 # Updated version detection. 
+]
 version "0.2"
 description "pixie is a free, open source web application that will help you quickly create your own website"
 website "http://www.getpixie.co.uk/"
