@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "PJIRC" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-02-28
+Plugin.define do
+name "PJIRC"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-02-28
+]
 version "0.1"
 description "PJIRC is the best free java irc client available. It can be run as an applet or stand alone and it is fully opensource."
 website "http://www.pjirc.it/"
