@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Posterita-POS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-18
+Plugin.define do
+name "Posterita-POS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-18
+]
 version "0.1"
 description "Posterita POS is a full web POS for large distribution and multi-site Point of Sale for thousands of users. Posterita POS is built on Adempiere/ERP."
 website "http://www.posterita.com/"
