@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Pressflow" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-18
+Plugin.define do
+name "Pressflow"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-18
+]
 version "0.1"
 description "Pressflow is a distribution of Drupal with integrated performance, scalability, availability, and testing enhancements."
 website "http://pressflow.org/"
