@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Proliphix-Thermostat" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-09
+Plugin.define do
+name "Proliphix-Thermostat"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-09
+]
 version "0.1"
 description "Network thermostats specifically designed for Internet access and control. They provide the features and functions of a conventional programmable thermostat with an easy-to-use, browser-based interface that significantly simplifies HVAC programming and control."
 website "http://www.proliphix.com/"
