@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Puppet-Dashboard" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-02-20
+Plugin.define do
+name "Puppet-Dashboard"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-02-20
+]
 version "0.1"
 description "The Puppet Dashboard is a web interface and reporting tool for a Puppet installation."
 website "http://projects.puppetlabs.com/projects/dashboard"
