@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Puridiom" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-07-14
+Plugin.define do
+name "Puridiom"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-07-14
+]
 version "0.1"
 description "Puridiom - eProcurement software"
 website "http://www.puridiom.com/"
