@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "qTranslate" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-09
+Plugin.define do
+name "qTranslate"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-09
+]
 version "0.1"
 description "qTranslate Wordpress plugin"
 website "http://www.qianqin.de/qtranslate/"
