@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "QuiXplorer" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-16
+Plugin.define do
+name "QuiXplorer"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-16
+]
 version "0.1"
 description "QuiXplorer is a multi-user, web-based file-manager. It allows you to manage and/or share files over the internet, or an intranet."
 website "http://quixplorer.sourceforge.net/"
