@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Red-Lion-HMI" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-17
+Plugin.define do
+name "Red-Lion-HMI"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-17
+]
 version "0.1"
 description "Red Lion's G3 operator interface panels give you complete HMI (Human Machine Interface) functionality for PLCs, motor drives and other communications-capable devices. With Ethernet as standard on all G3 models, you can network-enable any serial devices connected to the panel."
 website "http://www.redlion.net/"
