@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Redaxscript" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-22
+Plugin.define do
+name "Redaxscript"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-22
+]
 version "0.1"
 description "Redaxscript is a free, PHP and MySQL driven website engine for small business and private websites. It's ultra lightweight, simple and customizable."
 website "http://redaxscript.com/"
