@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Reinvigorate" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-07-20
+Plugin.define do
+name "Reinvigorate"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-07-20
+]
 version "0.1"
 description "Reinvigorate measures your influence on the web in real-time. Simple, real-time web analytics + heatmaps."
 website "http://www.reinvigorate.net/"
