@@ -2,14 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-# Version 0.2
-# removed :name & :certainty=>100
-
-Plugin.define "RoundCube" do
-author "Andrew Horton"
+Plugin.define do
+name "RoundCube"
+authors [
+  "Andrew Horton",
+  # v0.2 # removed :name & :certainty=>100
+]
 version "0.2"
 description "Opensource Webmail written in PHP"
 website "http://roundcube.net/"
@@ -25,7 +25,7 @@ matches [
 ]
 
 # Set-Cookie: roundcube_sessid=573c9cce97436b17e4ab02d83747efb2; path=/
-def passive
+passive do
 	m=[]
 	m << {:name=>"roundcube_sessid cookie" } if @headers["set-cookie"] =~ /roundcube_sessid/i		
 	m
