@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-03-02 #
-# Updated version detection
-##
-Plugin.define "RunCMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-11
+Plugin.define do
+name "RunCMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-11
+  # v0.2 # 2011-03-02 # Updated version detection. 
+]
 version "0.2"
 description "RunCms is Ease Of Use for webmasters. One of the worlds finest free CMS systems."
 website "www.runcms.org/"
