@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "ruTorrent" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-13
+Plugin.define do
+name "ruTorrent"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-13
+]
 version "0.1"
 description "ruTorrent is a front-end for the popular Bittorrent client rTorrent."
 website "http://code.google.com/p/rutorrent/"
@@ -16,7 +19,7 @@ website "http://code.google.com/p/rutorrent/"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# WWW-Authenticate realm
