@@ -1,19 +1,16 @@
-# coding: ascii-8bit
 ##
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-25 #
-# Updated version detection
-##
-##
-# Version 0.3 # 2011-02-25 #
-# Updated powered by match
-##
-Plugin.define "S-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-30
+Plugin.define do
+name "S-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-30
+  # v0.3 # 2011-02-25 # Updated powered by match. 
+  # v0.2 # 2011-02-25 # Updated version detection. 
+]
 version "0.3"
 description "CMS"
 website "http://www.matteoiammarrone.com/public/s-cms/"
