@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SABnzbd" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-05
+Plugin.define do
+name "SABnzbd"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-05
+]
 version "0.1"
 description "SABnzbd is an Open Source Binary Newsreader written in Python."
 website "http://sabnzbd.org/"
@@ -28,7 +31,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# WWW-Authenticate # realm="SABnzbd"
