@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Saman-Portal" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-13
+Plugin.define do
+name "Saman-Portal"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-13
+]
 version "0.1"
 description "Saman Portal"
 website "http://www.sis-eg.com/"
