@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Sawmill" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-20
+Plugin.define do
+name "Sawmill"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-20
+]
 version "0.1"
 description "Sawmill is a universal log analysis/reporting tool for almost any log including web, media, email, security, network and application logs."
 website "http://www.sawmill.net/"
