@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SazCart" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-22
+Plugin.define do
+name "SazCart"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-22
+]
 version "0.1"
 description "SazCart is a simple & powerful shopping cart script. With SazCart you can quickly and easily setup an online store. Then customize it to exactly how you want it to work & look."
 website "http://www.sazcart.com/"
