@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-03-06 #
-# Updated OS detection
-##
-Plugin.define "SegPub" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-02-19
+Plugin.define do
+name "SegPub"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-02-19
+  # v0.2 # 2011-03-06 # Updated OS detection. 
+]
 version "0.2"
 description "SegPub, a hosting solutions provider based in Sydney, Australia"
 website "http://segpub.net/"
@@ -22,7 +23,7 @@ website "http://segpub.net/"
 
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Server: SegPache
