@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SentinelServer" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-15
+Plugin.define do
+name "SentinelServer"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-15
+]
 version "0.1"
 description "Monitor application performance and availability"
 website "http://www.ymor.eu/"
