@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Silex-Print-Server" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-03-08
+Plugin.define do
+name "Silex-Print-Server"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-03-08
+]
 version "0.1"
 description "Silex Print Server - Print servers connect printers directly to the network so that multiple PCs can share them."
 website "http://www.silexamerica.com/"
@@ -35,7 +38,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# HTTP Server Header
