@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SiteMajic" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-04-24
+Plugin.define do
+name "SiteMajic"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-04-24
+]
 version "0.1"
 description "SiteMajic - Web Content Management System service"
 website "http://www.sitemajic.com/"
