@@ -2,12 +2,17 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SLAED-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-09-12
-version "0.1"
-description "Homepage: http://slaed.net/"
+Plugin.define do
+name "SLAED-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-09-12
+  "Andrew Horton", # v0.2 # 2019-07-10 # Added website field.
+]
+version "0.2"
+description ""
+website "http://slaed.net/"
 
 # Google results as at 2011-09-12 #
 # 268 for "Powered by SLAED CMS"
