@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SlingBox" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-11-17
+Plugin.define do
+name "SlingBox"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-11-17
+]
 version "0.1"
 description "The Slingbox is a TV streaming media device that encodes video for transmission over the Internet"
 website "http://slingbox.com/"
