@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SmodCMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-16
+Plugin.define do
+name "SmodCMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-16
+]
 version "0.1"
 description "SmodCMS"
 website "http://www.smod.pl/"
