@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Snare" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-08-12
+Plugin.define do
+name "Snare"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-08-12
+]
 version "0.1"
 description "Snare - Snare Server Remote Control web interface"
 website "http://www.intersectalliance.com/projects/"
