@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "SocketTimesheet" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-11-08
+Plugin.define do
+name "SocketTimesheet"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-11-08
+]
 version "0.1"
 description "PHP Timesheet web application"
 website "http://www.sockettimesheet.com/"
