@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Sockso" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-03-16
+Plugin.define do
+name "Sockso"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-03-16
+]
 version "0.1"
 description "Sockso is a free, open-source, personal music host server"
 website "http://sockso.pu-gh.com/"
