@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Sphider" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-23
+Plugin.define do
+name "Sphider"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-23
+]
 version "0.1"
 description "Sphider is a lightweight web spider and search engine written in PHP, using MySQL as its back end database."
 website "http://www.sphider.eu/"
