@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Sphinx" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-07-04
+Plugin.define do
+name "Sphinx"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-07-04
+]
 version "0.1"
 description "Sphinx is a tool that makes it easy to create intelligent and beautiful documentation"
 website "http://sphinx.pocoo.org/"
