@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "StarDot-NetCam" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-07-18
+Plugin.define do
+name "StarDot-NetCam"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-07-18
+]
 version "0.1"
 description "Stardot network camera web interface"
 website "http://www.stardot-tech.com/ "
