@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "StatusNet" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-21
+Plugin.define do
+name "StatusNet"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-21
+]
 version "0.1"
 description "StatusNet's Open Source social software enables organizations to collaborate, share insights and build relationships in real time."
 website "http://status.net/"
