@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Swiki" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-24
+Plugin.define do
+name "Swiki"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-24
+]
 version "0.1"
 description "Swiki is a popular implementation of Ward Cunningham's WikiWikiWeb that runs under Comanche."
 website "http://wiki.squeak.org/swiki/"
@@ -29,7 +32,7 @@ matches [
 ]
 
 # Passive #
-def passive
+passive do
 	m=[]
 
 	# Version Detection # Squeak / Comanche / Swiki
