@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Symantec-Client-Security" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-19
+Plugin.define do
+name "Symantec-Client-Security"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-11-19
+]
 version "0.1"
 description "Symantec Client Security"
 website "http://www.symantec.com"
