@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Taurus-Server-Appliance" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-19
+Plugin.define do
+name "Taurus-Server-Appliance"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-19
+]
 version "0.1"
 description "The Taurus Server Appliance is an all-in-one networking device solution for the small to midsize business."
 website "http://www.celestix.com/"
