@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-17 # Andrew Horton
-# Added website parameter and description
-##
-Plugin.define "TCMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-29
+Plugin.define do
+name "TCMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-29
+  "Andrew Horton", # v0.2 # 2016-04-17 # Added website parameter and description. 
+]
 version "0.2"
 description "Content management system by Tanzarine Technology Ltd"
 website "http://www.tanzarine.co.uk/Articles/cms.html"
@@ -24,7 +25,7 @@ matches [
 { :ghdb=>'"powered by TCMS"', :certainty=>75 },
 ]
 
-def passive
+passive do
         m=[]
 
 	# TCMS_SESS_ID cookie
