@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "TeveoLive-Video-Broadcast-Software" do
-author "Brendan Coles <bcoles@gmail.com>" # 2015-05-05
+Plugin.define do
+name "TeveoLive-Video-Broadcast-Software"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2015-05-05
+]
 version "0.1"
 description "TeveoLive webcam - Homepage [offline]: http://www.teveo.com/"
 
