@@ -2,16 +2,19 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
+Plugin.define do
+name "Textpattern"
+authors [
+  "Tonmoy Saikia",
+  "Andrew Horton", # v0.2 # Removed the aggressive function as it causes false postives 
+  # Andrew Horton # v0.3 # 2019-07-10 # Added website field.
 
-# Version 0.2 by Andrew Horton
-# Removed the aggressive function as it causes false postives
-
-Plugin.define "Textpattern" do
-author "Tonmoy Saikia"
-version "0.2"
-description "A flexible, elegant and easy-to-use CMS. Homepage:http://textpattern.com/"
+]
+version "0.3"
+description "A flexible, elegant and easy-to-use CMS."
+website "http://textpattern.com/"
 
 
 matches [
