@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "th-ERP" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-22
+Plugin.define do
+name "th-ERP"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-22
+]
 version "0.1"
 description "ERP application, including point-of-sale (POS), stock (inventory/warehouse), purchase, payables, receivables, general ledger (accounting), payroll, human resource (HR), time tracking, project management. th-ERP is written in PHP and using MySQL."
 website "http://sourceforge.net/projects/therp/"
