@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-23 # Andrew Horton
-# Moved patterns from passive function to matches[]
-##
-Plugin.define "TiVo" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-21
+Plugin.define do
+name "TiVo"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-21
+  "Andrew Horton", # v0.2 # 2016-04-23 # Moved patterns from passive function to matches[]. 
+]
 version "0.2"
 description "TiVo is a digital video recorder developed and marketed by TiVo, Inc."
 website "http://www.tivo.com/"
