@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "TMW-Imaging" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-11-16
+Plugin.define do
+name "TMW-Imaging"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-11-16
+]
 version "0.1"
 description "TMW Imaging - Document management system"
 website "http://www.tmwsystems.com/imaging"
