@@ -2,14 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-# Version 0.2
-# removed :certainty=>100 & :name. convert :regexp to :text
-
-Plugin.define "ToshibaPrinter" do
-author "Andrew Horton"
+Plugin.define do
+name "ToshibaPrinter"
+authors [
+  "Andrew Horton",
+  # v0.2 #  removed :certainty=>100 & :name. convert :regexp to :text
+]
 version "0.2"
 description "Toshiba printer Top Access"
 
