@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Truition" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-01-30
+Plugin.define do
+name "Truition"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-01-30
+]
 version "0.1"
 description "CDC eCommerce - On Demand eCommerce and Online Auction Software - formerly Truition"
 website "http://www.truition.com/"
