@@ -2,14 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-
-# Version 0.2
-# removed :certainty=>100 & :name
-
-Plugin.define "TypoLight" do
-author "Andrew Horton"
+Plugin.define do
+name "TypoLight"
+authors [
+  "Andrew Horton",
+  # v0.2 # removed :certainty=>100 & :name
+]
 version "0.2"
 description "TypoLight is an OpenSource CMS written in PHP"
 website "www.typolight.org"
@@ -26,7 +26,7 @@ matches [
 # <title>Hydro Energie Roth :: TYPOlight Open Source CMS 2.8</title>
 # TYPOlight webCMS :: TYPOlight webCMS 2.7
 
-def aggressive
+aggressive do
 	m=[]
 	
 	target = URI.join(@base_uri.to_s,"/typolight/").to_s
