@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 #
-# Updated version detection
-##
-Plugin.define "uPortal" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-13
+Plugin.define do
+name "uPortal"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-13
+  # v0.2 # Updated version detection. 
+]
 version "0.2"
 description "uPortal"
 
@@ -34,7 +35,7 @@ matches [
 
 ]
 
-def passive
+passive do
         m=[]
 
 	if @headers["uportal-version"] =~ /uPortal_rel-([\-0-9]+)/i
