@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "VamCart" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-07-18
+Plugin.define do
+name "VamCart"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-07-18
+]
 version "0.1"
 description "VamCart - CakePHP Based Open Source Shopping Cart"
 website "http://vamcart.com/"
