@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-24 #
-# Updated version detection
-##
-Plugin.define "vbPortal" do
-author "Brendan Coles <bcoles@gmail.com>"
+Plugin.define do
+name "vbPortal"
+authors [
+  "Brendan Coles <bcoles@gmail.com>",
+  # v0.2 # 2011-02-24 # Updated version detection. 
+]
 version "0.2"
 description "Portal and CMS for vBulletin"
 website "http://www.vbportal.com/"
