@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "VLC-Web-Interface" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-06-20
+Plugin.define do
+name "VLC-Web-Interface"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-06-20
+]
 version "0.1"
 description "Web interface for VideoLAN media player"
 website "http://www.videolan.org/"
