@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Web-Wiz-Rich-Text-Editor" do
-author "Brendan Coles <bcoles@gmail.com>" # 2013-04-01
+Plugin.define do
+name "Web-Wiz-Rich-Text-Editor"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2013-04-01
+]
 version "0.1"
 description "Web Wiz Rich Text Editor"
 website "http://www.richtexteditor.org/"
