@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "web2Project" do
-author "Brendan Coles <bcoles@gmail.com>" # 2012-11-02
+Plugin.define do
+name "web2Project"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2012-11-02
+]
 version "0.1"
 description "web2Project is a Free Open Source business-oriented Project Management System (PMS)"
 website "http://web2project.net/"
