@@ -2,12 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# 2014-10-13 # Napz
-##
-Plugin.define "Web2py" do
-author "Napz <napzs@rocketmail.com>"
+Plugin.define do
+name "Web2py"
+authors [
+  "Napz <napzs@rocketmail.com>", # 2014-10-13
+]
 version "0.1"
 description "Web2py - Free open source full-stack framework written in Pytho"
 website "http://www.web2py.com/"
@@ -28,4 +29,4 @@ matches [
 ]
 
 
-end
\ No newline at end of file
+end
