@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "WebAsyst-Shop-Script" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-08-29
+Plugin.define do
+name "WebAsyst-Shop-Script"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-08-29
+]
 version "0.1"
 description "Shop-Script . ecommerce platform for creating online stores. Available as PHP software and hosted service."
 website "http://www.shop-script.com/"
