@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "WEBCOMpro-CMS" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-08-14
+Plugin.define do
+name "WEBCOMpro-CMS"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-08-14
+]
 version "0.1"
 description "WEBCOMpro CMS"
 website "http://www.webcompro-cms.com/"
