@@ -2,13 +2,18 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Werkzeug" do
-author "Brendan Coles <bcoles@gmail.com>" # 2015-04-30
-version "0.1"
-description "Werkzeug is a WSGI utility library for Python. - Homepage: http://werkzeug.pocoo.org/"
+Plugin.define do
+name "Werkzeug"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2015-04-30
+  "Andrew Horton", # v0.2 # 2019-07-10 # Added website field.
 
+]
+version "0.2"
+description "Werkzeug is a WSGI utility library for Python."
+website "http://werkzeug.pocoo.org/"
 # About 2667 ShodanHQ results for server:Werkzeug @ 2015-04-30
 
 matches [
