@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "Windows-Remote-Printing" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-04-19
+Plugin.define do
+name "Windows-Remote-Printing"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-04-19
+]
 version "0.1"
 description "The Windows remote printing interface displays networked printers, print job owner usernames and internal IP addresses."
 
