@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2011-02-25 #
-# Updated version detection
-##
-Plugin.define "WoW-Raid-Manager" do
-author "Brendan Coles <bcoles@gmail.com>" # 2010-06-16
+Plugin.define do
+name "WoW-Raid-Manager"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2010-06-16
+  # v0.2 # 2011-02-25 # Updated version detection. 
+]
 version "0.2"
 description "WoW Raid Manager or WRM for short is a PHP based application supporting World of Warcraft guilds."
 website "http://www.wowraidmanager.net/"
