@@ -2,13 +2,14 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-# Version 0.2 # 2016-04-23 # Andrew Horton
-# Moved patterns from passive function to matches[]
-##
-Plugin.define "Xerver" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-05-20
+Plugin.define do
+name "Xerver"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-05-20
+  "Andrew Horton", # v0.2 # 2016-04-23 # Moved patterns from passive function to matches[]. 
+]
 version "0.2"
 description "Xerver is an advanced free GNU GPL Web and FTP server."
 website "http://www.javascript.nu/xerver/"
