@@ -2,10 +2,13 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "XOOPS-Cube" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-12-11
+Plugin.define do
+name "XOOPS-Cube"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # 2011-12-11
+]
 version "0.1"
 description "XOOPS Cube is an Open Source Web Application Platform"
 website "http://xoopscube.org/"
