@@ -2,11 +2,15 @@
 # This file is part of WhatWeb and may be subject to
 # redistribution and commercial restrictions. Please see the WhatWeb
 # web site for more information on licensing and terms of use.
-# http://www.morningstarsecurity.com/research/whatweb
+# https://www.morningstarsecurity.com/research/whatweb
 ##
-Plugin.define "XWiki" do
-author "Brendan Coles <bcoles@gmail.com>" # 2011-11-08
-version "0.1"
+Plugin.define do
+name "XWiki"
+authors [
+  "Brendan Coles <bcoles@gmail.com>", # v0.1 # 2011-11-08
+  "Andrew Horton", # v0.2 # 2019-07-10 # Fix warning: character class has duplicated range
+]
+version "0.2"
 description "XWiki - Open Source Wiki and Content-Oriented Application Platform"
 website "http://www.xwiki.org/"
 
@@ -34,7 +38,7 @@ matches [
 { :text=>'<div id="xwikilicence">' },
 
 # Version Detection # div id="xwikiplatformversion"
-{ :version=>/<div id="xwikiplatformversion">(Powered by )?(XWiki Enterprise )?([^\s^<^>]+)/, :offset=>2 },
+{ :version=>/<div id="xwikiplatformversion">(Powered by )?(XWiki Enterprise )?([^\s<>]+)/, :offset=>2 },
 
 ]
 
